#
# spec file for package wxlua
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global wx_version %(wx-config --release | sed 's/\\.//')
%define binds webview;gl;xrc;xml;net;media;propgrid;richtext;aui;stc;html;adv;core;base
%define sover 3_1_0_0
Name:           wxlua
Version:        3.1.0.0+42
Release:        2.10
Summary:        Lua bindings for wxWidgets
License:        GPL-2.0-or-later WITH WxWindows-exception-3.1
Group:          Development/Languages/Other
URL:            https://github.com/pkulchenko/wxlua
Source:         %{name}-%{version}.tar.xz
Source99:       wxlua-rpmlintrc
BuildRequires:  ccache
BuildRequires:  cmake >= 2.8
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  lua54-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  wxGTK3-devel >= 3.1.3
BuildRequires:  pkgconfig(glu)

%description
Lua bindings for wxWidgets cross-patform GUI toolkit;
supports Lua 5.1, 5.2, 5.3, 5.4, LuaJIT and wxWidgets 3.x

%package -n lib%{name}
Summary:        Set of Lua bindings to the C++ wxWidgets cross-platform GUI library
Group:          System/Libraries
Requires:       libwxlua-wx%{wx_version}-%{sover} = %{version}
Requires:       libwxlua_bind-wx%{wx_version}-%{sover} = %{version}
Requires:       libwxlua_debug-wx%{wx_version}-%{sover} = %{version}
Requires:       libwxlua_debugger-wx%{wx_version}-%{sover} = %{version}

%description -n lib%{name}
wxLua is a set of bindings to the C++ wxWidgets cross-platform GUI library for
the Lua programming language. Nearly all of the functionality of wxWidgets is
exposed to Lua, meaning that your programs can have windows, dialogs, menus,
toolbars, controls, image loading and saving, drawing, sockets, streams,
printing, clipboard access... and much more.

%package -n libwxlua-wx%{wx_version}-%{sover}
Summary:        Lua bindings to the C++ wxWidgets cross-platform GUI library
Group:          System/Libraries

%description -n libwxlua-wx%{wx_version}-%{sover}
wxLua is a set of bindings to the C++ wxWidgets cross-platform GUI library for
the Lua programming language. Nearly all of the functionality of wxWidgets is
exposed to Lua, meaning that your programs can have windows, dialogs, menus,
toolbars, controls, image loading and saving, drawing, sockets, streams,
printing, clipboard access... and much more.

%package -n libwxlua_bind-wx%{wx_version}-%{sover}
Summary:        Lua bindings to the C++ wxWidgets cross-platform GUI library
Group:          System/Libraries

%description -n libwxlua_bind-wx%{wx_version}-%{sover}
wxLua is a set of bindings to the C++ wxWidgets cross-platform GUI library for
the Lua programming language. Nearly all of the functionality of wxWidgets is
exposed to Lua, meaning that your programs can have windows, dialogs, menus,
toolbars, controls, image loading and saving, drawing, sockets, streams,
printing, clipboard access... and much more.

%package -n libwxlua_debug-wx%{wx_version}-%{sover}
Summary:        Lua bindings to the C++ wxWidgets cross-platform GUI library
Group:          System/Libraries

%description -n libwxlua_debug-wx%{wx_version}-%{sover}
wxLua is a set of bindings to the C++ wxWidgets cross-platform GUI library for
the Lua programming language. Nearly all of the functionality of wxWidgets is
exposed to Lua, meaning that your programs can have windows, dialogs, menus,
toolbars, controls, image loading and saving, drawing, sockets, streams,
printing, clipboard access... and much more.

%package -n libwxlua_debugger-wx%{wx_version}-%{sover}
Summary:        Lua bindings to the C++ wxWidgets cross-platform GUI library
Group:          System/Libraries

%description -n libwxlua_debugger-wx%{wx_version}-%{sover}
wxLua is a set of bindings to the C++ wxWidgets cross-platform GUI library for
the Lua programming language. Nearly all of the functionality of wxWidgets is
exposed to Lua, meaning that your programs can have windows, dialogs, menus,
toolbars, controls, image loading and saving, drawing, sockets, streams,
printing, clipboard access... and much more.

%package devel
Summary:        Development files of lib%{name}
Group:          Development/Languages/C and C++
Requires:       lib%{name} = %{version}

%description devel
This package contains files to be used in your C++ programs to embed a Lua
interpreter with the wxWidgets API.

%prep
%setup -q

cd wxLua
sed -r -i 's|LIBRARY DESTINATION .*$|LIBRARY DESTINATION %{_lib}|' CMakeLists.txt

%build
cd wxLua/build
cmake .. \
	-DCMAKE_CXX_FLAGS="-DwxLUA_USE_wxTranslations=0" \
	-DwxWidgets_CONFIG_EXECUTABLE=%{_bindir}/wx-config \
	-DwxLua_LUA_LIBRARY_BUILD_SHARED=TRUE \
	-DwxLua_LUA_LIBRARY_USE_BUILTIN=FALSE \
	-DwxLua_LUA_LIBRARY_VERSION=%{lua_version} \
	-DwxLua_LUA_INCLUDE_DIR=%{lua_incdir} \
	-DwxLua_LUA_LIBRARY=%{_libdir}/liblua%{lua_version}.so.5 \
	-DBUILD_SHARED_LIBS=TRUE \
	-DwxWidgets_COMPONENTS="%{binds}" \
	-DwxLuaBind_COMPONENTS="%{binds}" \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DCMAKE_SKIP_RPATH=TRUE

pushd modules/luamodule
make %{?_smp_mflags}
popd

make %{?_smp_mflags}

%install
cd wxLua
%cmake_install

rm -f %{buildroot}%{_bindir}/lua{,c}

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
install -p art/wxlualogo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
chmod -x %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/wxlualogo.svg

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/
install -p art/wxlualogo.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/

mkdir -p %{buildroot}%{_datadir}/applications/
install -p distrib/autopackage/wxlua.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

install -Dm644 distrib/autopackage/wxlua.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml

mkdir -p %{buildroot}%{_libdir}/lua/%{lua_version}/
mv %{buildroot}%{_libdir}/libwx.so %{buildroot}%{_libdir}/lua/%{lua_version}/wx.so

sed 's-#!/usr/bin/env lua-#!/usr/bin/lua%{lua_version}-g' -i %{buildroot}%{_datadir}/wxlua/apps/wxluafreeze/*

%post -n libwxlua-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%postun -n libwxlua-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%post -n libwxlua_bind-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%postun -n libwxlua_bind-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%post -n libwxlua_debug-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%postun -n libwxlua_debug-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%post -n libwxlua_debugger-wx%{wx_version}-%{sover} -p /sbin/ldconfig
%postun -n libwxlua_debugger-wx%{wx_version}-%{sover} -p /sbin/ldconfig

%files
%{_bindir}/wxLua
%{_bindir}/wxLuaCan
%{_bindir}/wxLuaFreeze
%{_datadir}/wxlua
%exclude %{_datadir}/wxlua/*.cmake
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/mime/packages/%{name}.xml

%files -n lib%{name}
%{_libdir}/lua/%{lua_version}/wx.so

%files -n libwxlua-wx%{wx_version}-%{sover}
%{_libdir}/libwxlua-wx%{wx_version}*.so

%files -n libwxlua_bind-wx%{wx_version}-%{sover}
%{_libdir}/libwxlua_bind-wx%{wx_version}*.so

%files -n libwxlua_debug-wx%{wx_version}-%{sover}
%{_libdir}/libwxlua_debug-wx%{wx_version}*.so

%files -n libwxlua_debugger-wx%{wx_version}-%{sover}
%{_libdir}/libwxlua_debugger-wx%{wx_version}*.so

%files devel
%{_includedir}/wxlua/
%dir %{_datadir}/wxlua
%{_datadir}/wxlua/*.cmake

%changelog
* Wed Apr 12 2023 Callum Farmer <gmbr3@opensuse.org>
- Move files accidentally placed in devel to main package
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add a rpmlintrc file to ignore false positive in 15.4
* Mon Aug 29 2022 christophe@krop.fr
- Update to version 3.1.0.0+42:
  * Improve build against wxWidgets 3.2.0-rc1
  * Updated luaopen_wx to always initialize.
  * Fixed wxBitmap error.
  * Missing methods in wxGraphicsPenInfo are implemented
  * wxMouseEvent methods are updated for wxWidgets 3.1
  * cmake: add imm32 to MINGW_EXTRA_LIBS
  * wxLuaDataObjectSimple::GetDataHere allows wxMemoryBuffer as
    a return value
  * wxLuaDataObjectSimple::GetDataHere calls the derived method
    incorrectly
  * DataViewCtrl: ExpandChildren method added for 3.1.5 and above
  * wxPen::SetDashes(), GetDashes() are implemented
  * Updated cmake config to better recognize GTK3 libraries
  * Updated wx-config targets Makefile to fix reference to Lua
    folder
  * Updated Makefile to fix reference to Lua folder
  * wxYELLOW etc. and wxTheColourDatabase are implemented
  * wxEVT_SEARCH and wxEVT_SEARCH_CANCEL require >=3.1.1
- set CMAKE_SKIP_RPATH. wxlua writes incorrect RUNPATH to
  libraries and executables.
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop cppcheck Buildrequires: seems not to be used.
* Wed Apr 21 2021 gmbr3@opensuse.org
- Update to version 3.1.0.0+27:
  * Compilation fixed for Lua 5.4
  * wxSearchCtrl bindings updated to add `SetValue`.
  * wxSearchCtrl bindings updated to add `GetValue`.
  * wxSearchCtrl binding added.
  * Fixed compilation issue with GenericGetHeader
  * Fixed compilation with wxwidgets prior to 3.1.5
  * Updated examples to use GetBitnessName instead of GetArchName
  * Added wxBitness instead of deprecated wxArchitecture
  * Add target dependencies to bindings Makefile
  * Updated example to use proper/current SetColour method name
  * Updated wxLUA_USE_wxTranslations scope to allow encodings to
    be used independently
  * Updated wxLUA_USE* setting handling to allow overwrites
    from command line
  * Add wxLUA_USE_wxTranslations option to control
    wxTranslations compilation
  * Reorganized wxTranslations version checks in prep for
    adding wxLUA_USE check
- Removed wxMemoryBuffer.patch: merged
- Disable translations which cause build failure
- Follow shared library packaging policy
- Use Lua 5.4
* Sun Jun 28 2020 Matthias Mailänder <mailaender@opensuse.org>
- Added wxMemoryBuffer.patch (will be fixed next release)
* Sat Jun 13 2020 Matthias Mailänder <mailaender@opensuse.org>
- Drop desktop.patch (included upstream)
- Update to version 3.0.0.8
- Drop wx-webview.patch (it is disabled by default now)
* Tue Dec 12 2017 mailaender@opensuse.org
- Update to the 3.1 series fork
- Drop wxlstate.patch
- Add desktop.patch
* Thu Sep  7 2017 jengelh@inai.de
- Add wx-webview.patch which disables building the Lua wrapper for
  of wxWebView, since that class is going away in the C++ part.
* Tue Jul 11 2017 tchvatal@suse.com
- Fix build with namespaced lua
* Thu Jul 21 2016 mailaender@opensuse.org
- install shared library and MIME files
* Thu Jul 21 2016 mailaender@opensuse.org
- initial packaging for openSUSE
